﻿using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Editors;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

/// <summary>
/// Interaction logic for MainWindow.xaml
/// </summary>
public partial class MainWindow : Window {

    public TestVM VM { get; set; }

    public MainWindow() {
        InitializeComponent();
        this.DataContext = VM = new TestVM();
        this.Loaded += (a, b) => {
            grdConvDocs.Records.ExpandAll(true);
        };
    }

    private void XamComboEditor_SelectedItemChanged(object sender, RoutedPropertyChangedEventArgs<object> e) {
        var docObjs = (((sender as XamComboEditor).DataContext as DataRecord).DataItem as ConvGroupedDocs).Docs;
        foreach (ConvDoc doc in docObjs) {
            doc.Type = (sender as XamComboEditor).Text;
        }
        VM.NotifyPropertyChanged("ConvDocs");
        System.Diagnostics.Debugger.Launch();
        // Test these underlying values. Why does XamDataGrid not reflect all of the sub collection values
        var testVal = VM.ConvDocs[0].Docs[0].Type;
        // testVal should be what was choosen in the combo editor, but the screen does not paint this value... 
        // If you can scoll away it does render, but how do we get real-time rendering? NotifyPropertyChanged does not appear to work?
    }

    private void XamComboEditor_Loaded(object sender, RoutedEventArgs e) {
        (sender as XamComboEditor).ItemsSource = VM.SynergyTypeList;     
    }
}

public class TestVM : BaseModel {

    /// <summary>
    /// Mock Data
    /// </summary>
    public TestVM() {
        var doc1 = new ConvGroupedDocs() { DocType = "Type A", Type = "", Docs = new ObservableCollection<ConvDoc>() };
        doc1.Docs.Add(new ConvDoc(){ FileName = "File A1", Type = "" });
        doc1.Docs.Add(new ConvDoc() { FileName = "File A2", Type = "" });
        doc1.Docs.Add(new ConvDoc() { FileName = "File A3", Type = "" });
        ConvDocs.Add(doc1);
        var doc2 = new ConvGroupedDocs() { DocType = "Type B", Type = "", Docs = new ObservableCollection<ConvDoc>() };
        doc2.Docs.Add(new ConvDoc() { FileName = "File B1", Type = "" });
        doc2.Docs.Add(new ConvDoc() { FileName = "File B2", Type = "" });
        doc2.Docs.Add(new ConvDoc() { FileName = "File B3", Type = "" });
        ConvDocs.Add(doc2);
        NotifyPropertyChanged("ConvDocs");
    }

    ObservableCollection<ConvGroupedDocs> _ConvDocs = new ObservableCollection<ConvGroupedDocs>();
    public ObservableCollection<ConvGroupedDocs> ConvDocs {
        get { return _ConvDocs; }
        set { _ConvDocs = value; NotifyPropertyChanged("ConvDocs"); }
    }

    public ObservableCollection<string> SynergyTypeList {
        get {
            var list = new ObservableCollection<string>();
            list.Add("A");
            list.Add("B");
            list.Add("C");
            return list;
        }
    }
}

public class ConvDoc {
    public string FileName { get; set; }
    public string Type { get; set; }

}

public class ConvGroupedDocs {
    public String DocType { get; set; }    
    public string Type { get; set; }
    public ObservableCollection<ConvDoc> Docs { get; set; }
}

